//
//  CurriculaItemCell.swift
//  schedule
//
//  Created by Илья Лошкарёв on 22.03.2018.
//  Copyright © 2018 SFEDU. All rights reserved.
//

import UIKit

extension UIStackView {
    func clear() {
        arrangedSubviews.forEach {
            removeArrangedSubview($0)
            $0.removeFromSuperview()
        }
    }
}

class LessonCell: UITableViewCell {
    @IBOutlet weak var timeLabel: UILabel!
    @IBOutlet weak var curriculaStack: UIStackView!
    
    static var outputTimeFormatter : DateFormatter = {
        let df = DateFormatter()
        df.dateFormat = "HH:mm"
        df.timeZone = TimeZone.current
        return df
    }()
    
    func setup(for timeslot: Timeslot?, with data: [CurriculaItem]?) {
        curriculaStack.clear()
        
        if let startDate = timeslot?.startTime.date,
            let endDate = timeslot?.endTime.date {
            timeLabel.text = LessonCell.outputTimeFormatter.string(from: startDate) + "\n" +  LessonCell.outputTimeFormatter.string(from: endDate)
        }
        
        if let curricula = data {
            for curriculaItem in curricula {
                // инстанцируем ячейку из файла интерфейса
                guard let nibData = Bundle.main.loadNibNamed("CurriculaItemView", owner: self, options: nil),
                    let curCell = nibData[0] as? CurriculaItemView
                else {
                    fatalError("Unexpected UI in Xib")
                }
                
                curCell.setup(for: curriculaItem)
                
                curCell.translatesAutoresizingMaskIntoConstraints = false
                curriculaStack.addArrangedSubview(curCell)
            }
        }
    }

}
