//
//  StubDataLoader.swift
//  schedule-connect
//
//  Created by Илья Лошкарёв on 12.04.2018.
//  Copyright © 2018 SFEDU. All rights reserved.
//

import Foundation

class StubDataLoader: DataLoaderTask {
    typealias DataType = StubSchedule
    
    let source: URL
    
    required init(from url: URL) {
        source = url
    }
    
    func decode(_ data: Data?) -> StubSchedule? {
        guard let data = data else {return nil}
        return try? JSONDecoder().decode(StubSchedule.self, from: data)
    }
    
    func perform(in session: URLSession, withCompletion completionHandler: @escaping (StubSchedule) -> (), withError errorHandler: ((DataLoaderError) -> ())?) {
        if source.pathComponents[0] == "/" {
            if let schedule = decode(try? Data(contentsOf: source))
            {
                completionHandler(schedule)
            }else {
               errorHandler?(.dataError(data: nil))
            }
        } else {
            session.dataTask(with: source) {
                [weak self] data, response, error in
                
                if error != nil {
                    errorHandler?(.sessionError(localizedDescription: error!.localizedDescription))
                    return
                }
                if let resp = response as? HTTPURLResponse {
                    if resp.statusCode >= 300 {
                        errorHandler?(.responseError(response: response))
                        return
                    }
                } else {
                    errorHandler?(.responseError(response: response))
                    return
                }
                
                if let schedule = self?.decode(data) {
                    completionHandler(schedule)
                } else {
                    errorHandler?(.dataError(data: data))
                }
            }
        }
        
    }
}
